@@ -1,11 +1,11 @@
 package Alien::LibYAML;
 
 use strict;
-use warnings FATAL => 'all';
-use utf8;
+use warnings;
+use 5.008001;
 use parent qw(Alien::Base);
 
-our $VERSION = 'v0.1.4'; # VERSION
+our $VERSION = 'v0.1.5'; # VERSION
 # ABSTRACT: Build and install libyaml, a C-based YAML parser and emitter
 
 1;
@@ -17,9 +17,17 @@ Alien::LibYAML - Build and install libyaml, a C-based YAML parser and emitter
 
 =head1 SYNOPSIS
 
-    my $libyaml = Alien::LibYAML->new;
-    say $libyaml->libs;
-    say $libyaml->cflags;
+In your C<Build.PL>:
+
+    use Alien::LibYAML;
+    use Module::Build;
+    
+    Module::Build->new(
+      ...
+      extra_compiler_flags => Alien::LibYAML->cflags,
+      extra_linker_flags   => Alien::LibYAML->libs,
+      ...
+    )->create_build_script;
 
 =head1 DESCRIPTION
 
@@ -38,8 +46,14 @@ Perl bindings for libyaml (library bundled with distribution).
 
 =head1 AUTHOR
 
+Original Author:
+
 Richard Simões C<< <rsimoes AT cpan DOT org> >>
 
+Current Maintainer:
+
+Graham Ollis C<< <plicease AT cpan DOT org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright © 2014 Richard Simões. libyaml written and copyrighted by Kirill
